=========================
residuals_weather_storage
=========================


.. image:: https://img.shields.io/pypi/v/rws_py.svg
        :target: https://pypi.python.org/pypi/rws_py

.. image:: https://img.shields.io/travis/spp-2403/rws_py.svg
        :target: https://travis-ci.com/spp-2403/rws_py

.. image:: https://readthedocs.org/projects/rws-py/badge/?version=latest
        :target: https://rws-py.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




SPP 2403 Analyze weather timeseries to estimate residual loads and energy storage design parameters, especially for Carnot Batteries.


* Free software: MIT
* Documentation: https://rws-py.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `briggySmalls/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`briggySmalls/cookiecutter-pypackage`: https://github.com/briggySmalls/cookiecutter-pypackage
